summaryrefslogtreecommitdiffstats
path: root/searchcore
diff options
context:
space:
mode:
Diffstat (limited to 'searchcore')
-rw-r--r--searchcore/src/vespa/searchcore/proton/attribute/flushableattribute.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/searchcore/src/vespa/searchcore/proton/attribute/flushableattribute.cpp b/searchcore/src/vespa/searchcore/proton/attribute/flushableattribute.cpp
index ae3edc93f6d..d9d269f1e91 100644
--- a/searchcore/src/vespa/searchcore/proton/attribute/flushableattribute.cpp
+++ b/searchcore/src/vespa/searchcore/proton/attribute/flushableattribute.cpp
@@ -170,7 +170,7 @@ FlushableAttribute::FlushableAttribute(const AttributeVectorSP attr,
if (config.basicType() == search::attribute::BasicType::Type::TENSOR &&
config.tensorType().is_dense() && config.hnsw_index_params().has_value())
{
- _replay_operation_cost = 100.0; // replaying operations to hnsw index is 100 times more expensive than reading from tls
+ _replay_operation_cost = 400.0; // replaying operations to hnsw index is 400 times more expensive than reading from tls
}
}